@@ -53,8 +53,8 @@ void gtkaml_attribute_set_name (GtkamlAttribute* self, const char* value) {
 	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_name = (g_free (self->priv->_name), NULL)), _tmp2);
-	g_object_notify (((GObject *) (self)), "name");
+	self->priv->_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_strdup (_tmp1)), self->priv->_name = (g_free (self->priv->_name), NULL), _tmp2);
+	g_object_notify ((GObject *) self, "name");
 }
 
 
@@ -70,8 +70,8 @@ void gtkaml_attribute_set_target_type (GtkamlAttribute* self, ValaSymbol* value)
 	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_target_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_target_type == NULL ? NULL : (self->priv->_target_type = (vala_code_node_unref (self->priv->_target_type), NULL))), _tmp2);
-	g_object_notify (((GObject *) (self)), "target-type");
+	self->priv->_target_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1)), (self->priv->_target_type == NULL) ? NULL : (self->priv->_target_type = (vala_code_node_unref (self->priv->_target_type), NULL)), _tmp2);
+	g_object_notify ((GObject *) self, "target-type");
 }
 
 
@@ -129,7 +129,7 @@ static void gtkaml_attribute_finalize (GObject* obj) {
 	GtkamlAttribute * self;
 	self = GTKAML_ATTRIBUTE (obj);
 	self->priv->_name = (g_free (self->priv->_name), NULL);
-	(self->priv->_target_type == NULL ? NULL : (self->priv->_target_type = (vala_code_node_unref (self->priv->_target_type), NULL)));
+	(self->priv->_target_type == NULL) ? NULL : (self->priv->_target_type = (vala_code_node_unref (self->priv->_target_type), NULL));
 	G_OBJECT_CLASS (gtkaml_attribute_parent_class)->finalize (obj);
 }
 
