@@ -21,9 +21,9 @@
  */
 
 #include "GtkamlClassDefinition.h"
-#include <vala/valasymbol.h>
 #include <gee/arraylist.h>
 #include <gee/collection.h>
+#include <vala/valasymbol.h>
 
 
 
@@ -92,12 +92,12 @@ GtkamlClassDefinition* gtkaml_class_definition_construct (GType object_type, Val
 	gtkaml_class_definition_set_definition_scope (self, definition_scope);
 	gtkaml_class_definition_set_parent_container (self, parent_container);
 	_tmp0 = NULL;
-	gtkaml_class_definition_set_attrs (self, ((GeeList*) ((_tmp0 = gee_array_list_new (GTKAML_TYPE_ATTRIBUTE, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal)))));
-	(_tmp0 == NULL ? NULL : (_tmp0 = (gee_collection_object_unref (_tmp0), NULL)));
+	gtkaml_class_definition_set_attrs (self, (GeeList*) (_tmp0 = gee_array_list_new (GTKAML_TYPE_ATTRIBUTE, (GBoxedCopyFunc) g_object_ref, g_object_unref, g_direct_equal)));
+	(_tmp0 == NULL) ? NULL : (_tmp0 = (gee_collection_object_unref (_tmp0), NULL));
 	gtkaml_class_definition_set_construct_method (self, NULL);
 	_tmp1 = NULL;
-	gtkaml_class_definition_set_children (self, ((GeeList*) ((_tmp1 = gee_array_list_new (GTKAML_TYPE_CLASS_DEFINITION, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal)))));
-	(_tmp1 == NULL ? NULL : (_tmp1 = (gee_collection_object_unref (_tmp1), NULL)));
+	gtkaml_class_definition_set_children (self, (GeeList*) (_tmp1 = gee_array_list_new (GTKAML_TYPE_CLASS_DEFINITION, (GBoxedCopyFunc) g_object_ref, g_object_unref, g_direct_equal)));
+	(_tmp1 == NULL) ? NULL : (_tmp1 = (gee_collection_object_unref (_tmp1), NULL));
 	gtkaml_class_definition_set_construct_code (self, NULL);
 	gtkaml_class_definition_set_preconstruct_code (self, NULL);
 	return self;
@@ -112,14 +112,14 @@ GtkamlClassDefinition* gtkaml_class_definition_new (ValaSourceReference* source_
 void gtkaml_class_definition_add_attribute (GtkamlClassDefinition* self, GtkamlAttribute* attr) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (attr != NULL);
-	gee_collection_add (((GeeCollection*) (self->priv->_attrs)), attr);
+	gee_collection_add ((GeeCollection*) self->priv->_attrs, attr);
 }
 
 
 void gtkaml_class_definition_add_child (GtkamlClassDefinition* self, GtkamlClassDefinition* child) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (child != NULL);
-	gee_collection_add (((GeeCollection*) (self->priv->_children)), child);
+	gee_collection_add ((GeeCollection*) self->priv->_children, child);
 }
 
 
@@ -135,8 +135,8 @@ void gtkaml_class_definition_set_source_reference (GtkamlClassDefinition* self,
 	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_source_reference = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_source_reference_ref (_tmp1))), (self->priv->_source_reference == NULL ? NULL : (self->priv->_source_reference = (vala_source_reference_unref (self->priv->_source_reference), NULL))), _tmp2);
-	g_object_notify (((GObject *) (self)), "source-reference");
+	self->priv->_source_reference = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_source_reference_ref (_tmp1)), (self->priv->_source_reference == NULL) ? NULL : (self->priv->_source_reference = (vala_source_reference_unref (self->priv->_source_reference), NULL)), _tmp2);
+	g_object_notify ((GObject *) self, "source-reference");
 }
 
 
@@ -152,8 +152,8 @@ void gtkaml_class_definition_set_identifier (GtkamlClassDefinition* self, const
 	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_identifier = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_identifier = (g_free (self->priv->_identifier), NULL)), _tmp2);
-	g_object_notify (((GObject *) (self)), "identifier");
+	self->priv->_identifier = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_strdup (_tmp1)), self->priv->_identifier = (g_free (self->priv->_identifier), NULL), _tmp2);
+	g_object_notify ((GObject *) self, "identifier");
 }
 
 
@@ -168,13 +168,13 @@ char* gtkaml_class_definition_get_base_full_name (GtkamlClassDefinition* self) {
 		const char* _tmp0;
 		_tmp1 = NULL;
 		_tmp0 = NULL;
-		baseful_name = (_tmp1 = (_tmp0 = vala_symbol_get_name (((ValaSymbol*) (self->priv->_base_type))), (_tmp0 == NULL ? NULL : g_strdup (_tmp0))), (baseful_name = (g_free (baseful_name), NULL)), _tmp1);
+		baseful_name = (_tmp1 = (_tmp0 = vala_symbol_get_name ((ValaSymbol*) self->priv->_base_type), (_tmp0 == NULL) ? NULL : g_strdup (_tmp0)), baseful_name = (g_free (baseful_name), NULL), _tmp1);
 	} else {
 		char* _tmp3;
 		char* _tmp2;
 		_tmp3 = NULL;
 		_tmp2 = NULL;
-		baseful_name = (_tmp3 = g_strconcat ((_tmp2 = g_strconcat (self->priv->_base_ns, ".", NULL)), vala_symbol_get_name (((ValaSymbol*) (self->priv->_base_type))), NULL), (baseful_name = (g_free (baseful_name), NULL)), _tmp3);
+		baseful_name = (_tmp3 = g_strconcat (_tmp2 = g_strconcat (self->priv->_base_ns, ".", NULL), vala_symbol_get_name ((ValaSymbol*) self->priv->_base_type), NULL), baseful_name = (g_free (baseful_name), NULL), _tmp3);
 		_tmp2 = (g_free (_tmp2), NULL);
 	}
 	return baseful_name;
@@ -193,8 +193,8 @@ void gtkaml_class_definition_set_base_ns (GtkamlClassDefinition* self, const cha
 	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_base_ns = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_base_ns = (g_free (self->priv->_base_ns), NULL)), _tmp2);
-	g_object_notify (((GObject *) (self)), "base-ns");
+	self->priv->_base_ns = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_strdup (_tmp1)), self->priv->_base_ns = (g_free (self->priv->_base_ns), NULL), _tmp2);
+	g_object_notify ((GObject *) self, "base-ns");
 }
 
 
@@ -210,8 +210,8 @@ void gtkaml_class_definition_set_base_type (GtkamlClassDefinition* self, ValaCla
 	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_base_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_base_type == NULL ? NULL : (self->priv->_base_type = (vala_code_node_unref (self->priv->_base_type), NULL))), _tmp2);
-	g_object_notify (((GObject *) (self)), "base-type");
+	self->priv->_base_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1)), (self->priv->_base_type == NULL) ? NULL : (self->priv->_base_type = (vala_code_node_unref (self->priv->_base_type), NULL)), _tmp2);
+	g_object_notify ((GObject *) self, "base-type");
 }
 
 
@@ -227,8 +227,8 @@ void gtkaml_class_definition_set_attrs (GtkamlClassDefinition* self, GeeList* va
 	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_attrs = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : gee_collection_object_ref (_tmp1))), (self->priv->_attrs == NULL ? NULL : (self->priv->_attrs = (gee_collection_object_unref (self->priv->_attrs), NULL))), _tmp2);
-	g_object_notify (((GObject *) (self)), "attrs");
+	self->priv->_attrs = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : gee_collection_object_ref (_tmp1)), (self->priv->_attrs == NULL) ? NULL : (self->priv->_attrs = (gee_collection_object_unref (self->priv->_attrs), NULL)), _tmp2);
+	g_object_notify ((GObject *) self, "attrs");
 }
 
 
@@ -241,7 +241,7 @@ GtkamlClassDefinition* gtkaml_class_definition_get_parent_container (GtkamlClass
 void gtkaml_class_definition_set_parent_container (GtkamlClassDefinition* self, GtkamlClassDefinition* value) {
 	g_return_if_fail (self != NULL);
 	self->priv->_parent_container = value;
-	g_object_notify (((GObject *) (self)), "parent-container");
+	g_object_notify ((GObject *) self, "parent-container");
 }
 
 
@@ -257,8 +257,8 @@ void gtkaml_class_definition_set_children (GtkamlClassDefinition* self, GeeList*
 	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_children = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : gee_collection_object_ref (_tmp1))), (self->priv->_children == NULL ? NULL : (self->priv->_children = (gee_collection_object_unref (self->priv->_children), NULL))), _tmp2);
-	g_object_notify (((GObject *) (self)), "children");
+	self->priv->_children = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : gee_collection_object_ref (_tmp1)), (self->priv->_children == NULL) ? NULL : (self->priv->_children = (gee_collection_object_unref (self->priv->_children), NULL)), _tmp2);
+	g_object_notify ((GObject *) self, "children");
 }
 
 
@@ -271,7 +271,7 @@ DefinitionScope gtkaml_class_definition_get_definition_scope (GtkamlClassDefinit
 void gtkaml_class_definition_set_definition_scope (GtkamlClassDefinition* self, DefinitionScope value) {
 	g_return_if_fail (self != NULL);
 	self->priv->_definition_scope = value;
-	g_object_notify (((GObject *) (self)), "definition-scope");
+	g_object_notify ((GObject *) self, "definition-scope");
 }
 
 
@@ -287,8 +287,8 @@ void gtkaml_class_definition_set_construct_method (GtkamlClassDefinition* self,
 	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_construct_method = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_construct_method == NULL ? NULL : (self->priv->_construct_method = (g_object_unref (self->priv->_construct_method), NULL))), _tmp2);
-	g_object_notify (((GObject *) (self)), "construct-method");
+	self->priv->_construct_method = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_object_ref (_tmp1)), (self->priv->_construct_method == NULL) ? NULL : (self->priv->_construct_method = (g_object_unref (self->priv->_construct_method), NULL)), _tmp2);
+	g_object_notify ((GObject *) self, "construct-method");
 }
 
 
@@ -304,8 +304,8 @@ void gtkaml_class_definition_set_add_method (GtkamlClassDefinition* self, Gtkaml
 	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_add_method = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_add_method == NULL ? NULL : (self->priv->_add_method = (g_object_unref (self->priv->_add_method), NULL))), _tmp2);
-	g_object_notify (((GObject *) (self)), "add-method");
+	self->priv->_add_method = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_object_ref (_tmp1)), (self->priv->_add_method == NULL) ? NULL : (self->priv->_add_method = (g_object_unref (self->priv->_add_method), NULL)), _tmp2);
+	g_object_notify ((GObject *) self, "add-method");
 }
 
 
@@ -321,8 +321,8 @@ void gtkaml_class_definition_set_construct_code (GtkamlClassDefinition* self, co
 	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_construct_code = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_construct_code = (g_free (self->priv->_construct_code), NULL)), _tmp2);
-	g_object_notify (((GObject *) (self)), "construct-code");
+	self->priv->_construct_code = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_strdup (_tmp1)), self->priv->_construct_code = (g_free (self->priv->_construct_code), NULL), _tmp2);
+	g_object_notify ((GObject *) self, "construct-code");
 }
 
 
@@ -338,8 +338,8 @@ void gtkaml_class_definition_set_preconstruct_code (GtkamlClassDefinition* self,
 	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_preconstruct_code = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_preconstruct_code = (g_free (self->priv->_preconstruct_code), NULL)), _tmp2);
-	g_object_notify (((GObject *) (self)), "preconstruct-code");
+	self->priv->_preconstruct_code = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_strdup (_tmp1)), self->priv->_preconstruct_code = (g_free (self->priv->_preconstruct_code), NULL), _tmp2);
+	g_object_notify ((GObject *) self, "preconstruct-code");
 }
 
 
@@ -470,14 +470,14 @@ static void gtkaml_class_definition_instance_init (GtkamlClassDefinition * self)
 static void gtkaml_class_definition_finalize (GObject* obj) {
 	GtkamlClassDefinition * self;
 	self = GTKAML_CLASS_DEFINITION (obj);
-	(self->priv->_source_reference == NULL ? NULL : (self->priv->_source_reference = (vala_source_reference_unref (self->priv->_source_reference), NULL)));
+	(self->priv->_source_reference == NULL) ? NULL : (self->priv->_source_reference = (vala_source_reference_unref (self->priv->_source_reference), NULL));
 	self->priv->_identifier = (g_free (self->priv->_identifier), NULL);
 	self->priv->_base_ns = (g_free (self->priv->_base_ns), NULL);
-	(self->priv->_base_type == NULL ? NULL : (self->priv->_base_type = (vala_code_node_unref (self->priv->_base_type), NULL)));
-	(self->priv->_attrs == NULL ? NULL : (self->priv->_attrs = (gee_collection_object_unref (self->priv->_attrs), NULL)));
-	(self->priv->_children == NULL ? NULL : (self->priv->_children = (gee_collection_object_unref (self->priv->_children), NULL)));
-	(self->priv->_construct_method == NULL ? NULL : (self->priv->_construct_method = (g_object_unref (self->priv->_construct_method), NULL)));
-	(self->priv->_add_method == NULL ? NULL : (self->priv->_add_method = (g_object_unref (self->priv->_add_method), NULL)));
+	(self->priv->_base_type == NULL) ? NULL : (self->priv->_base_type = (vala_code_node_unref (self->priv->_base_type), NULL));
+	(self->priv->_attrs == NULL) ? NULL : (self->priv->_attrs = (gee_collection_object_unref (self->priv->_attrs), NULL));
+	(self->priv->_children == NULL) ? NULL : (self->priv->_children = (gee_collection_object_unref (self->priv->_children), NULL));
+	(self->priv->_construct_method == NULL) ? NULL : (self->priv->_construct_method = (g_object_unref (self->priv->_construct_method), NULL));
+	(self->priv->_add_method == NULL) ? NULL : (self->priv->_add_method = (g_object_unref (self->priv->_add_method), NULL));
 	self->priv->_construct_code = (g_free (self->priv->_construct_code), NULL);
 	self->priv->_preconstruct_code = (g_free (self->priv->_preconstruct_code), NULL);
 	G_OBJECT_CLASS (gtkaml_class_definition_parent_class)->finalize (obj);
