@@ -44,7 +44,7 @@ GtkamlComplexAttribute* gtkaml_complex_attribute_construct (GType object_type, c
 	g_return_val_if_fail (name != NULL, NULL);
 	g_return_val_if_fail (complex_type != NULL, NULL);
 	self = g_object_newv (object_type, 0, NULL);
-	gtkaml_attribute_set_name (((GtkamlAttribute*) (self)), name);
+	gtkaml_attribute_set_name ((GtkamlAttribute*) self, name);
 	gtkaml_complex_attribute_set_complex_type (self, complex_type);
 	return self;
 }
@@ -67,8 +67,8 @@ void gtkaml_complex_attribute_set_complex_type (GtkamlComplexAttribute* self, Gt
 	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_complex_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_complex_type == NULL ? NULL : (self->priv->_complex_type = (g_object_unref (self->priv->_complex_type), NULL))), _tmp2);
-	g_object_notify (((GObject *) (self)), "complex-type");
+	self->priv->_complex_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_object_ref (_tmp1)), (self->priv->_complex_type == NULL) ? NULL : (self->priv->_complex_type = (g_object_unref (self->priv->_complex_type), NULL)), _tmp2);
+	g_object_notify ((GObject *) self, "complex-type");
 }
 
 
@@ -118,7 +118,7 @@ static void gtkaml_complex_attribute_instance_init (GtkamlComplexAttribute * sel
 static void gtkaml_complex_attribute_finalize (GObject* obj) {
 	GtkamlComplexAttribute * self;
 	self = GTKAML_COMPLEX_ATTRIBUTE (obj);
-	(self->priv->_complex_type == NULL ? NULL : (self->priv->_complex_type = (g_object_unref (self->priv->_complex_type), NULL)));
+	(self->priv->_complex_type == NULL) ? NULL : (self->priv->_complex_type = (g_object_unref (self->priv->_complex_type), NULL));
 	G_OBJECT_CLASS (gtkaml_complex_attribute_parent_class)->finalize (obj);
 }
 
