@@ -25,6 +25,8 @@
 #include <gee/hashmap.h>
 #include <gee/map.h>
 #include <gee/collection.h>
+#include <gee/iterable.h>
+#include <gee/iterator.h>
 #include <glib/gstdio.h>
 #include <vala/valareport.h>
 #include <vala/valasourcereference.h>
@@ -141,7 +143,16 @@ static gboolean gtkaml_key_file_wrapper_has_key (GtkamlKeyFileWrapper* self, con
 	g_return_val_if_fail (key != NULL, FALSE);
 	inner_error = NULL;
 	{
-		return g_key_file_has_key (self->key_file, group, key, &inner_error);
+		gboolean _tmp0;
+		_tmp0 = g_key_file_has_key (self->key_file, group, key, &inner_error);
+		if (inner_error != NULL) {
+			if (inner_error->domain == G_KEY_FILE_ERROR) {
+				goto __catch4_g_key_file_error;
+			}
+			g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
+			g_clear_error (&inner_error);
+		}
+		return _tmp0;
 	}
 	goto __finally4;
 	__catch4_g_key_file_error:
@@ -150,8 +161,8 @@ static gboolean gtkaml_key_file_wrapper_has_key (GtkamlKeyFileWrapper* self, con
 		e = inner_error;
 		inner_error = NULL;
 		{
-			gboolean _tmp1;
-			return (_tmp1 = FALSE, (e == NULL ? NULL : (e = (g_error_free (e), NULL))), _tmp1);
+			gboolean _tmp2;
+			return (_tmp2 = FALSE, (e == NULL) ? NULL : (e = (g_error_free (e), NULL)), _tmp2);
 		}
 	}
 	__finally4:
@@ -166,10 +177,18 @@ static char** gtkaml_key_file_wrapper_get_string_list (GtkamlKeyFileWrapper* sel
 	g_return_val_if_fail (key != NULL, NULL);
 	inner_error = NULL;
 	{
+		char** _tmp2;
+		gint _tmp1_length1;
 		gint _tmp0;
 		char** _tmp1;
-		_tmp1 = NULL;
-		return (_tmp1 = g_key_file_get_string_list (self->key_file, group, key, &_tmp0, &inner_error), (*result_length1) = _tmp0, _tmp1);
+		char** _tmp3;
+		_tmp2 = NULL;
+		_tmp1 = (_tmp2 = g_key_file_get_string_list (self->key_file, group, key, &_tmp0, &inner_error), _tmp1_length1 = _tmp0, _tmp2);
+		if (inner_error != NULL) {
+			goto __catch5_g_error;
+		}
+		_tmp3 = NULL;
+		return (_tmp3 = _tmp1, *result_length1 = _tmp1_length1, _tmp3);
 	}
 	goto __finally5;
 	__catch5_g_error:
@@ -178,11 +197,11 @@ static char** gtkaml_key_file_wrapper_get_string_list (GtkamlKeyFileWrapper* sel
 		e = inner_error;
 		inner_error = NULL;
 		{
-			char** _tmp3;
-			char** _tmp4;
-			_tmp3 = NULL;
-			_tmp4 = NULL;
-			return (_tmp4 = (_tmp3 = g_new0 (char*, 0 + 1), (*result_length1) = 0, _tmp3), (e == NULL ? NULL : (e = (g_error_free (e), NULL))), _tmp4);
+			char** _tmp5;
+			char** _tmp6;
+			_tmp5 = NULL;
+			_tmp6 = NULL;
+			return (_tmp6 = (_tmp5 = g_new0 (char*, 0 + 1), *result_length1 = 0, _tmp5), (e == NULL) ? NULL : (e = (g_error_free (e), NULL)), _tmp6);
 		}
 	}
 	__finally5:
@@ -217,7 +236,7 @@ static GObject * gtkaml_key_file_wrapper_constructor (GType type, guint n_constr
 	{
 		GKeyFile* _tmp0;
 		_tmp0 = NULL;
-		self->key_file = (_tmp0 = g_key_file_new (), (self->key_file == NULL ? NULL : (self->key_file = (g_key_file_free (self->key_file), NULL))), _tmp0);
+		self->key_file = (_tmp0 = g_key_file_new (), (self->key_file == NULL) ? NULL : (self->key_file = (g_key_file_free (self->key_file), NULL)), _tmp0);
 	}
 	return obj;
 }
@@ -237,7 +256,7 @@ static void gtkaml_key_file_wrapper_instance_init (GtkamlKeyFileWrapper * self)
 static void gtkaml_key_file_wrapper_finalize (GObject* obj) {
 	GtkamlKeyFileWrapper * self;
 	self = GTKAML_KEY_FILE_WRAPPER (obj);
-	(self->key_file == NULL ? NULL : (self->key_file = (g_key_file_free (self->key_file), NULL)));
+	(self->key_file == NULL) ? NULL : (self->key_file = (g_key_file_free (self->key_file), NULL));
 	G_OBJECT_CLASS (gtkaml_key_file_wrapper_parent_class)->finalize (obj);
 }
 
@@ -254,14 +273,14 @@ static GType gtkaml_key_file_wrapper_get_type (void) {
 
 GeeReadOnlyList* gtkaml_implicits_store_get_implicits_dirs (GtkamlImplicitsStore* self) {
 	g_return_val_if_fail (self != NULL, NULL);
-	return gee_read_only_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) (g_strdup)), g_free, self->priv->implicits_dirs);
+	return gee_read_only_list_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, self->priv->implicits_dirs);
 }
 
 
 void gtkaml_implicits_store_add_implicits_dir (GtkamlImplicitsStore* self, const char* directory) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (directory != NULL);
-	gee_collection_add (((GeeCollection*) (self->priv->implicits_dirs)), directory);
+	gee_collection_add ((GeeCollection*) self->priv->implicits_dirs, directory);
 }
 
 
@@ -271,60 +290,58 @@ static GeeList* gtkaml_implicits_store_get_ns (GtkamlImplicitsStore* self, const
 	g_return_val_if_fail (ns != NULL, NULL);
 	inner_error = NULL;
 	if (gee_map_contains (self->priv->loaded_ns, ns)) {
-		return ((GeeList*) (gee_map_get (self->priv->loaded_ns, ns)));
+		return (GeeList*) gee_map_get (self->priv->loaded_ns, ns);
 	} else {
 		GeeArrayList* key_file_list;
-		key_file_list = gee_array_list_new (GTKAML_TYPE_KEY_FILE_WRAPPER, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal);
+		key_file_list = gee_array_list_new (GTKAML_TYPE_KEY_FILE_WRAPPER, (GBoxedCopyFunc) g_object_ref, g_object_unref, g_direct_equal);
 		{
-			GeeList* implicits_dir_collection;
-			int implicits_dir_it;
-			implicits_dir_collection = self->priv->implicits_dirs;
-			for (implicits_dir_it = 0; implicits_dir_it < gee_collection_get_size (GEE_COLLECTION (implicits_dir_collection)); implicits_dir_it = implicits_dir_it + 1) {
+			GeeIterator* implicits_dir_it;
+			implicits_dir_it = gee_iterable_iterator ((GeeIterable*) self->priv->implicits_dirs);
+			while (gee_iterator_next (implicits_dir_it)) {
 				char* implicits_dir;
-				implicits_dir = ((char*) (gee_list_get (GEE_LIST (implicits_dir_collection), implicits_dir_it)));
-				{
-					char* _tmp1;
-					char* _tmp2;
-					char* file_name;
-					_tmp1 = NULL;
-					_tmp2 = NULL;
-					file_name = (_tmp2 = g_build_filename (implicits_dir, (_tmp1 = g_strconcat (ns, ".implicits", NULL)), NULL), (_tmp1 = (g_free (_tmp1), NULL)), _tmp2);
-					if (g_file_test (file_name, G_FILE_TEST_EXISTS)) {
-						GtkamlKeyFileWrapper* key_file_wrapper;
-						key_file_wrapper = gtkaml_key_file_wrapper_new ();
-						{
-							g_key_file_load_from_file (key_file_wrapper->key_file, file_name, G_KEY_FILE_NONE, &inner_error);
-							if (inner_error != NULL) {
-								goto __catch6_g_error;
-							}
-							gee_collection_add (((GeeCollection*) (key_file_list)), key_file_wrapper);
+				char* _tmp1;
+				char* _tmp2;
+				char* file_name;
+				implicits_dir = (char*) gee_iterator_get (implicits_dir_it);
+				_tmp1 = NULL;
+				_tmp2 = NULL;
+				file_name = (_tmp2 = g_build_filename (implicits_dir, _tmp1 = g_strconcat (ns, ".implicits", NULL), NULL), _tmp1 = (g_free (_tmp1), NULL), _tmp2);
+				if (g_file_test (file_name, G_FILE_TEST_EXISTS)) {
+					GtkamlKeyFileWrapper* key_file_wrapper;
+					key_file_wrapper = gtkaml_key_file_wrapper_new ();
+					{
+						g_key_file_load_from_file (key_file_wrapper->key_file, file_name, G_KEY_FILE_NONE, &inner_error);
+						if (inner_error != NULL) {
+							goto __catch6_g_error;
 						}
-						goto __finally6;
-						__catch6_g_error:
-						{
-							GError * e;
-							e = inner_error;
-							inner_error = NULL;
-							{
-								char* _tmp3;
-								_tmp3 = NULL;
-								vala_report_warning (NULL, (_tmp3 = g_strdup_printf ("Invalid implicits file %s", file_name)));
-								_tmp3 = (g_free (_tmp3), NULL);
-								(e == NULL ? NULL : (e = (g_error_free (e), NULL)));
-							}
-						}
-						__finally6:
-						;
-						(key_file_wrapper == NULL ? NULL : (key_file_wrapper = (g_object_unref (key_file_wrapper), NULL)));
+						gee_collection_add ((GeeCollection*) key_file_list, key_file_wrapper);
 					}
-					implicits_dir = (g_free (implicits_dir), NULL);
-					file_name = (g_free (file_name), NULL);
+					goto __finally6;
+					__catch6_g_error:
+					{
+						GError * e;
+						e = inner_error;
+						inner_error = NULL;
+						{
+							char* _tmp3;
+							_tmp3 = NULL;
+							vala_report_warning (NULL, _tmp3 = g_strdup_printf ("Invalid implicits file %s", file_name));
+							_tmp3 = (g_free (_tmp3), NULL);
+							(e == NULL) ? NULL : (e = (g_error_free (e), NULL));
+						}
+					}
+					__finally6:
+					;
+					(key_file_wrapper == NULL) ? NULL : (key_file_wrapper = (g_object_unref (key_file_wrapper), NULL));
 				}
+				implicits_dir = (g_free (implicits_dir), NULL);
+				file_name = (g_free (file_name), NULL);
 			}
+			(implicits_dir_it == NULL) ? NULL : (implicits_dir_it = (gee_collection_object_unref (implicits_dir_it), NULL));
 		}
 		/*even an empty list does it: so that we don't scan the directories again*/
-		gee_map_set (self->priv->loaded_ns, ns, ((GeeList*) (key_file_list)));
-		return ((GeeList*) (key_file_list));
+		gee_map_set (self->priv->loaded_ns, ns, (GeeList*) key_file_list);
+		return (GeeList*) key_file_list;
 	}
 }
 
@@ -336,49 +353,47 @@ GeeList* gtkaml_implicits_store_get_adds (GtkamlImplicitsStore* self, const char
 	g_return_val_if_fail (self != NULL, NULL);
 	g_return_val_if_fail (ns != NULL, NULL);
 	g_return_val_if_fail (class_name != NULL, NULL);
-	adds = ((GeeList*) (gee_array_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) (g_strdup)), g_free, g_direct_equal)));
+	adds = (GeeList*) gee_array_list_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, g_direct_equal);
 	kf_ns = gtkaml_implicits_store_get_ns (self, ns);
 	{
-		GeeList* kfw_collection;
-		int kfw_it;
-		kfw_collection = kf_ns;
-		for (kfw_it = 0; kfw_it < gee_collection_get_size (GEE_COLLECTION (kfw_collection)); kfw_it = kfw_it + 1) {
+		GeeIterator* kfw_it;
+		kfw_it = gee_iterable_iterator ((GeeIterable*) kf_ns);
+		while (gee_iterator_next (kfw_it)) {
 			GtkamlKeyFileWrapper* kfw;
-			kfw = ((GtkamlKeyFileWrapper*) (gee_list_get (GEE_LIST (kfw_collection), kfw_it)));
-			{
-				if (gtkaml_key_file_wrapper_has_key (kfw, class_name, "adds")) {
-					char** _tmp1;
-					gint kf_adds_length1;
-					gint _tmp0;
-					char** kf_adds;
-					_tmp1 = NULL;
-					kf_adds = (_tmp1 = gtkaml_key_file_wrapper_get_string_list (kfw, class_name, "adds", &_tmp0), kf_adds_length1 = _tmp0, _tmp1);
-					{
-						char** add_collection;
-						int add_collection_length1;
-						int add_it;
-						add_collection = kf_adds;
-						add_collection_length1 = kf_adds_length1;
-						for (add_it = 0; (kf_adds_length1 != -1 && add_it < kf_adds_length1) || (kf_adds_length1 == -1 && add_collection[add_it] != NULL); add_it = add_it + 1) {
-							const char* _tmp2;
-							char* add;
-							_tmp2 = NULL;
-							add = (_tmp2 = add_collection[add_it], (_tmp2 == NULL ? NULL : g_strdup (_tmp2)));
-							{
-								/*stderr.printf ("store contains %s\n", add);*/
-								gee_collection_add (((GeeCollection*) (adds)), add);
-								add = (g_free (add), NULL);
-							}
+			kfw = (GtkamlKeyFileWrapper*) gee_iterator_get (kfw_it);
+			if (gtkaml_key_file_wrapper_has_key (kfw, class_name, "adds")) {
+				char** _tmp1;
+				gint kf_adds_length1;
+				gint _tmp0;
+				char** kf_adds;
+				_tmp1 = NULL;
+				kf_adds = (_tmp1 = gtkaml_key_file_wrapper_get_string_list (kfw, class_name, "adds", &_tmp0), kf_adds_length1 = _tmp0, _tmp1);
+				{
+					char** add_collection;
+					int add_collection_length1;
+					int add_it;
+					add_collection = kf_adds;
+					add_collection_length1 = kf_adds_length1;
+					for (add_it = 0; ((kf_adds_length1 != -1) && (add_it < kf_adds_length1)) || ((kf_adds_length1 == -1) && (add_collection[add_it] != NULL)); add_it = add_it + 1) {
+						const char* _tmp2;
+						char* add;
+						_tmp2 = NULL;
+						add = (_tmp2 = add_collection[add_it], (_tmp2 == NULL) ? NULL : g_strdup (_tmp2));
+						{
+							/*stderr.printf ("store contains %s\n", add);*/
+							gee_collection_add ((GeeCollection*) adds, add);
+							add = (g_free (add), NULL);
 						}
 					}
-					kf_adds = (_vala_array_free (kf_adds, kf_adds_length1, ((GDestroyNotify) (g_free))), NULL);
 				}
-				(kfw == NULL ? NULL : (kfw = (g_object_unref (kfw), NULL)));
+				kf_adds = (_vala_array_free (kf_adds, kf_adds_length1, (GDestroyNotify) g_free), NULL);
 			}
+			(kfw == NULL) ? NULL : (kfw = (g_object_unref (kfw), NULL));
 		}
+		(kfw_it == NULL) ? NULL : (kfw_it = (gee_collection_object_unref (kfw_it), NULL));
 	}
 	_tmp3 = NULL;
-	return (_tmp3 = adds, (kf_ns == NULL ? NULL : (kf_ns = (gee_collection_object_unref (kf_ns), NULL))), _tmp3);
+	return (_tmp3 = adds, (kf_ns == NULL) ? NULL : (kf_ns = (gee_collection_object_unref (kf_ns), NULL)), _tmp3);
 }
 
 
@@ -388,67 +403,68 @@ GeeList* gtkaml_implicits_store_get_method_parameters (GtkamlImplicitsStore* sel
 	g_return_val_if_fail (ns != NULL, NULL);
 	g_return_val_if_fail (class_name != NULL, NULL);
 	g_return_val_if_fail (method_name != NULL, NULL);
-	parameters = ((GeeList*) (gee_array_list_new (GTKAML_TYPE_IMPLICITS_PARAMETER, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal)));
+	parameters = (GeeList*) gee_array_list_new (GTKAML_TYPE_IMPLICITS_PARAMETER, (GBoxedCopyFunc) g_object_ref, g_object_unref, g_direct_equal);
 	{
-		GeeList* kfw_collection;
-		int kfw_it;
-		kfw_collection = gtkaml_implicits_store_get_ns (self, ns);
-		for (kfw_it = 0; kfw_it < gee_collection_get_size (GEE_COLLECTION (kfw_collection)); kfw_it = kfw_it + 1) {
+		GeeList* _tmp0;
+		GeeIterator* _tmp1;
+		GeeIterator* kfw_it;
+		_tmp0 = NULL;
+		_tmp1 = NULL;
+		kfw_it = (_tmp1 = gee_iterable_iterator ((GeeIterable*) (_tmp0 = gtkaml_implicits_store_get_ns (self, ns))), (_tmp0 == NULL) ? NULL : (_tmp0 = (gee_collection_object_unref (_tmp0), NULL)), _tmp1);
+		while (gee_iterator_next (kfw_it)) {
 			GtkamlKeyFileWrapper* kfw;
-			kfw = ((GtkamlKeyFileWrapper*) (gee_list_get (GEE_LIST (kfw_collection), kfw_it)));
-			{
-				if (gtkaml_key_file_wrapper_has_key (kfw, class_name, method_name)) {
-					char** _tmp1;
-					gint kf_parameters_length1;
-					gint _tmp0;
-					char** kf_parameters;
-					GeeList* _tmp8;
-					_tmp1 = NULL;
-					kf_parameters = (_tmp1 = gtkaml_key_file_wrapper_get_string_list (kfw, class_name, method_name, &_tmp0), kf_parameters_length1 = _tmp0, _tmp1);
-					{
-						char** parameter_collection;
-						int parameter_collection_length1;
-						int parameter_it;
-						parameter_collection = kf_parameters;
-						parameter_collection_length1 = kf_parameters_length1;
-						for (parameter_it = 0; (kf_parameters_length1 != -1 && parameter_it < kf_parameters_length1) || (kf_parameters_length1 == -1 && parameter_collection[parameter_it] != NULL); parameter_it = parameter_it + 1) {
+			kfw = (GtkamlKeyFileWrapper*) gee_iterator_get (kfw_it);
+			if (gtkaml_key_file_wrapper_has_key (kfw, class_name, method_name)) {
+				char** _tmp3;
+				gint kf_parameters_length1;
+				gint _tmp2;
+				char** kf_parameters;
+				GeeList* _tmp10;
+				_tmp3 = NULL;
+				kf_parameters = (_tmp3 = gtkaml_key_file_wrapper_get_string_list (kfw, class_name, method_name, &_tmp2), kf_parameters_length1 = _tmp2, _tmp3);
+				{
+					char** parameter_collection;
+					int parameter_collection_length1;
+					int parameter_it;
+					parameter_collection = kf_parameters;
+					parameter_collection_length1 = kf_parameters_length1;
+					for (parameter_it = 0; ((kf_parameters_length1 != -1) && (parameter_it < kf_parameters_length1)) || ((kf_parameters_length1 == -1) && (parameter_collection[parameter_it] != NULL)); parameter_it = parameter_it + 1) {
+						const char* _tmp9;
+						char* parameter;
+						_tmp9 = NULL;
+						parameter = (_tmp9 = parameter_collection[parameter_it], (_tmp9 == NULL) ? NULL : g_strdup (_tmp9));
+						{
+							GtkamlImplicitsParameter* implicits_parameter;
+							char** _tmp4;
+							gint name_value_length1;
+							char** name_value;
+							char* _tmp6;
+							const char* _tmp5;
+							char* _tmp8;
 							const char* _tmp7;
-							char* parameter;
+							implicits_parameter = gtkaml_implicits_parameter_new ();
+							_tmp4 = NULL;
+							name_value = (_tmp4 = g_strsplit (parameter, "=", 0), name_value_length1 = -1, _tmp4);
+							_tmp6 = NULL;
+							_tmp5 = NULL;
+							implicits_parameter->name = (_tmp6 = (_tmp5 = name_value[0], (_tmp5 == NULL) ? NULL : g_strdup (_tmp5)), implicits_parameter->name = (g_free (implicits_parameter->name), NULL), _tmp6);
+							_tmp8 = NULL;
 							_tmp7 = NULL;
-							parameter = (_tmp7 = parameter_collection[parameter_it], (_tmp7 == NULL ? NULL : g_strdup (_tmp7)));
-							{
-								GtkamlImplicitsParameter* implicits_parameter;
-								char** _tmp2;
-								gint name_value_length1;
-								char** name_value;
-								char* _tmp4;
-								const char* _tmp3;
-								char* _tmp6;
-								const char* _tmp5;
-								implicits_parameter = gtkaml_implicits_parameter_new ();
-								_tmp2 = NULL;
-								name_value = (_tmp2 = g_strsplit (parameter, "=", 0), name_value_length1 = -1, _tmp2);
-								_tmp4 = NULL;
-								_tmp3 = NULL;
-								implicits_parameter->name = (_tmp4 = (_tmp3 = name_value[0], (_tmp3 == NULL ? NULL : g_strdup (_tmp3))), (implicits_parameter->name = (g_free (implicits_parameter->name), NULL)), _tmp4);
-								_tmp6 = NULL;
-								_tmp5 = NULL;
-								implicits_parameter->default_value = (_tmp6 = (_tmp5 = name_value[1], (_tmp5 == NULL ? NULL : g_strdup (_tmp5))), (implicits_parameter->default_value = (g_free (implicits_parameter->default_value), NULL)), _tmp6);
-								/*either null or not*/
-								gee_collection_add (((GeeCollection*) (parameters)), implicits_parameter);
-								parameter = (g_free (parameter), NULL);
-								(implicits_parameter == NULL ? NULL : (implicits_parameter = (g_object_unref (implicits_parameter), NULL)));
-								name_value = (_vala_array_free (name_value, name_value_length1, ((GDestroyNotify) (g_free))), NULL);
-							}
+							implicits_parameter->default_value = (_tmp8 = (_tmp7 = name_value[1], (_tmp7 == NULL) ? NULL : g_strdup (_tmp7)), implicits_parameter->default_value = (g_free (implicits_parameter->default_value), NULL), _tmp8);
+							/*either null or not*/
+							gee_collection_add ((GeeCollection*) parameters, implicits_parameter);
+							parameter = (g_free (parameter), NULL);
+							(implicits_parameter == NULL) ? NULL : (implicits_parameter = (g_object_unref (implicits_parameter), NULL));
+							name_value = (_vala_array_free (name_value, name_value_length1, (GDestroyNotify) g_free), NULL);
 						}
 					}
-					_tmp8 = NULL;
-					return (_tmp8 = parameters, (kf_parameters = (_vala_array_free (kf_parameters, kf_parameters_length1, ((GDestroyNotify) (g_free))), NULL)), (kfw == NULL ? NULL : (kfw = (g_object_unref (kfw), NULL))), (kfw_collection == NULL ? NULL : (kfw_collection = (gee_collection_object_unref (kfw_collection), NULL))), _tmp8);
 				}
-				(kfw == NULL ? NULL : (kfw = (g_object_unref (kfw), NULL)));
+				_tmp10 = NULL;
+				return (_tmp10 = parameters, kf_parameters = (_vala_array_free (kf_parameters, kf_parameters_length1, (GDestroyNotify) g_free), NULL), (kfw == NULL) ? NULL : (kfw = (g_object_unref (kfw), NULL)), (kfw_it == NULL) ? NULL : (kfw_it = (gee_collection_object_unref (kfw_it), NULL)), _tmp10);
 			}
+			(kfw == NULL) ? NULL : (kfw = (g_object_unref (kfw), NULL));
 		}
-		(kfw_collection == NULL ? NULL : (kfw_collection = (gee_collection_object_unref (kfw_collection), NULL)));
+		(kfw_it == NULL) ? NULL : (kfw_it = (gee_collection_object_unref (kfw_it), NULL));
 	}
 	return parameters;
 }
@@ -463,79 +479,78 @@ GeeList* gtkaml_implicits_store_determine_parameter_names_and_default_values (Gt
 	const char* _tmp1;
 	char* method_name;
 	GeeList* result_array;
-	GeeList* _tmp7;
+	GeeList* _tmp9;
 	g_return_val_if_fail (self != NULL, NULL);
 	g_return_val_if_fail (class_definition != NULL, NULL);
 	g_return_val_if_fail (method != NULL, NULL);
-	ns = vala_symbol_get_full_name (vala_symbol_get_parent_symbol (vala_symbol_get_parent_symbol (((ValaSymbol*) (method)))));
+	ns = vala_symbol_get_full_name (vala_symbol_get_parent_symbol (vala_symbol_get_parent_symbol ((ValaSymbol*) method)));
 	_tmp0 = NULL;
-	clazz = (_tmp0 = vala_symbol_get_name (vala_symbol_get_parent_symbol (((ValaSymbol*) (method)))), (_tmp0 == NULL ? NULL : g_strdup (_tmp0)));
+	clazz = (_tmp0 = vala_symbol_get_name (vala_symbol_get_parent_symbol ((ValaSymbol*) method)), (_tmp0 == NULL) ? NULL : g_strdup (_tmp0));
 	/*stderr.printf ("determine_parameter_names_and_default_values %s %s of %s.%s\n", class_definition.base_full_name, method.name, ns, clazz);*/
-	result = gee_array_list_new (GTKAML_TYPE_IMPLICITS_PARAMETER, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal);
+	result = gee_array_list_new (GTKAML_TYPE_IMPLICITS_PARAMETER, (GBoxedCopyFunc) g_object_ref, g_object_unref, g_direct_equal);
 	_tmp1 = NULL;
-	method_name = (_tmp1 = vala_symbol_get_name (((ValaSymbol*) (method))), (_tmp1 == NULL ? NULL : g_strdup (_tmp1)));
+	method_name = (_tmp1 = vala_symbol_get_name ((ValaSymbol*) method), (_tmp1 == NULL) ? NULL : g_strdup (_tmp1));
 	if (VALA_IS_CREATION_METHOD (method)) {
-		if (_vala_strcmp0 (vala_symbol_get_name (((ValaSymbol*) (method))), "new") != 0) {
+		if (_vala_strcmp0 (vala_symbol_get_name ((ValaSymbol*) method), "new") != 0) {
 			char* _tmp2;
 			_tmp2 = NULL;
-			method_name = (_tmp2 = g_strconcat ("new.", vala_symbol_get_name (((ValaSymbol*) (method))), NULL), (method_name = (g_free (method_name), NULL)), _tmp2);
+			method_name = (_tmp2 = g_strconcat ("new.", vala_symbol_get_name ((ValaSymbol*) method), NULL), method_name = (g_free (method_name), NULL), _tmp2);
 		}
 	} else {
 		char* _tmp3;
 		_tmp3 = NULL;
-		method_name = (_tmp3 = g_strconcat ("add.", vala_symbol_get_name (((ValaSymbol*) (method))), NULL), (method_name = (g_free (method_name), NULL)), _tmp3);
+		method_name = (_tmp3 = g_strconcat ("add.", vala_symbol_get_name ((ValaSymbol*) method), NULL), method_name = (g_free (method_name), NULL), _tmp3);
 	}
 	result_array = gtkaml_implicits_store_get_method_parameters (self, ns, clazz, method_name);
-	if (gee_collection_get_size (((GeeCollection*) (result_array))) != 0) {
+	if (gee_collection_get_size ((GeeCollection*) result_array) != 0) {
 		{
-			GeeList* result_item_collection;
-			int result_item_it;
-			result_item_collection = result_array;
-			for (result_item_it = 0; result_item_it < gee_collection_get_size (GEE_COLLECTION (result_item_collection)); result_item_it = result_item_it + 1) {
+			GeeIterator* result_item_it;
+			result_item_it = gee_iterable_iterator ((GeeIterable*) result_array);
+			while (gee_iterator_next (result_item_it)) {
 				GtkamlImplicitsParameter* result_item;
-				result_item = ((GtkamlImplicitsParameter*) (gee_list_get (GEE_LIST (result_item_collection), result_item_it)));
-				{
-					if (result_item->default_value != NULL) {
-					}
-					/*stderr.printf ("default value for %s=<%s>\n", result_item.name, result_item.default_value);*/
-					gee_collection_add (((GeeCollection*) (result)), result_item);
-					(result_item == NULL ? NULL : (result_item = (g_object_unref (result_item), NULL)));
+				result_item = (GtkamlImplicitsParameter*) gee_iterator_get (result_item_it);
+				if (result_item->default_value != NULL) {
 				}
+				/*stderr.printf ("default value for %s=<%s>\n", result_item.name, result_item.default_value);*/
+				gee_collection_add ((GeeCollection*) result, result_item);
+				(result_item == NULL) ? NULL : (result_item = (g_object_unref (result_item), NULL));
 			}
+			(result_item_it == NULL) ? NULL : (result_item_it = (gee_collection_object_unref (result_item_it), NULL));
 		}
 	} else {
 		{
-			GeeList* p_collection;
-			int p_it;
-			p_collection = vala_method_get_parameters (method);
-			for (p_it = 0; p_it < gee_collection_get_size (GEE_COLLECTION (p_collection)); p_it = p_it + 1) {
+			GeeList* _tmp4;
+			GeeIterator* _tmp5;
+			GeeIterator* p_it;
+			_tmp4 = NULL;
+			_tmp5 = NULL;
+			p_it = (_tmp5 = gee_iterable_iterator ((GeeIterable*) (_tmp4 = vala_method_get_parameters (method))), (_tmp4 == NULL) ? NULL : (_tmp4 = (gee_collection_object_unref (_tmp4), NULL)), _tmp5);
+			while (gee_iterator_next (p_it)) {
 				ValaFormalParameter* p;
-				p = ((ValaFormalParameter*) (gee_list_get (GEE_LIST (p_collection), p_it)));
-				{
-					if (!vala_formal_parameter_get_ellipsis (p)) {
-						GtkamlImplicitsParameter* new_implicits_parameter;
-						char* _tmp5;
-						const char* _tmp4;
-						char* _tmp6;
-						/*hack for add_with_parameters (widget, ...)*/
-						new_implicits_parameter = gtkaml_implicits_parameter_new ();
-						_tmp5 = NULL;
-						_tmp4 = NULL;
-						new_implicits_parameter->name = (_tmp5 = (_tmp4 = vala_symbol_get_name (((ValaSymbol*) (p))), (_tmp4 == NULL ? NULL : g_strdup (_tmp4))), (new_implicits_parameter->name = (g_free (new_implicits_parameter->name), NULL)), _tmp5);
-						_tmp6 = NULL;
-						new_implicits_parameter->default_value = (_tmp6 = NULL, (new_implicits_parameter->default_value = (g_free (new_implicits_parameter->default_value), NULL)), _tmp6);
-						/*here we can go for "zero"es and "false"s*/
-						gee_collection_add (((GeeCollection*) (result)), new_implicits_parameter);
-						(new_implicits_parameter == NULL ? NULL : (new_implicits_parameter = (g_object_unref (new_implicits_parameter), NULL)));
-					}
-					(p == NULL ? NULL : (p = (vala_code_node_unref (p), NULL)));
+				p = (ValaFormalParameter*) gee_iterator_get (p_it);
+				if (!vala_formal_parameter_get_ellipsis (p)) {
+					GtkamlImplicitsParameter* new_implicits_parameter;
+					char* _tmp7;
+					const char* _tmp6;
+					char* _tmp8;
+					/*hack for add_with_parameters (widget, ...)*/
+					new_implicits_parameter = gtkaml_implicits_parameter_new ();
+					_tmp7 = NULL;
+					_tmp6 = NULL;
+					new_implicits_parameter->name = (_tmp7 = (_tmp6 = vala_symbol_get_name ((ValaSymbol*) p), (_tmp6 == NULL) ? NULL : g_strdup (_tmp6)), new_implicits_parameter->name = (g_free (new_implicits_parameter->name), NULL), _tmp7);
+					_tmp8 = NULL;
+					new_implicits_parameter->default_value = (_tmp8 = NULL, new_implicits_parameter->default_value = (g_free (new_implicits_parameter->default_value), NULL), _tmp8);
+					/*here we can go for "zero"es and "false"s*/
+					gee_collection_add ((GeeCollection*) result, new_implicits_parameter);
+					(new_implicits_parameter == NULL) ? NULL : (new_implicits_parameter = (g_object_unref (new_implicits_parameter), NULL));
 				}
+				(p == NULL) ? NULL : (p = (vala_code_node_unref (p), NULL));
 			}
-			(p_collection == NULL ? NULL : (p_collection = (gee_collection_object_unref (p_collection), NULL)));
+			(p_it == NULL) ? NULL : (p_it = (gee_collection_object_unref (p_it), NULL));
 		}
 	}
-	_tmp7 = NULL;
-	return (_tmp7 = ((GeeList*) (result)), (ns = (g_free (ns), NULL)), (clazz = (g_free (clazz), NULL)), (method_name = (g_free (method_name), NULL)), (result_array == NULL ? NULL : (result_array = (gee_collection_object_unref (result_array), NULL))), _tmp7);
+	_tmp9 = NULL;
+	return (_tmp9 = (GeeList*) result, ns = (g_free (ns), NULL), clazz = (g_free (clazz), NULL), method_name = (g_free (method_name), NULL), (result_array == NULL) ? NULL : (result_array = (gee_collection_object_unref (result_array), NULL)), _tmp9);
 }
 
 
@@ -563,16 +578,16 @@ static void gtkaml_implicits_store_class_init (GtkamlImplicitsStoreClass * klass
 
 static void gtkaml_implicits_store_instance_init (GtkamlImplicitsStore * self) {
 	self->priv = GTKAML_IMPLICITS_STORE_GET_PRIVATE (self);
-	self->priv->implicits_dirs = ((GeeList*) (gee_array_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) (g_strdup)), g_free, g_str_equal)));
-	self->priv->loaded_ns = ((GeeMap*) (gee_hash_map_new (G_TYPE_STRING, ((GBoxedCopyFunc) (g_strdup)), g_free, GEE_TYPE_LIST, ((GBoxedCopyFunc) (gee_collection_object_ref)), gee_collection_object_unref, g_str_hash, g_str_equal, g_direct_equal)));
+	self->priv->implicits_dirs = (GeeList*) gee_array_list_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, g_str_equal);
+	self->priv->loaded_ns = (GeeMap*) gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, GEE_TYPE_LIST, (GBoxedCopyFunc) gee_collection_object_ref, gee_collection_object_unref, g_str_hash, g_str_equal, g_direct_equal);
 }
 
 
 static void gtkaml_implicits_store_finalize (GObject* obj) {
 	GtkamlImplicitsStore * self;
 	self = GTKAML_IMPLICITS_STORE (obj);
-	(self->priv->implicits_dirs == NULL ? NULL : (self->priv->implicits_dirs = (gee_collection_object_unref (self->priv->implicits_dirs), NULL)));
-	(self->priv->loaded_ns == NULL ? NULL : (self->priv->loaded_ns = (gee_collection_object_unref (self->priv->loaded_ns), NULL)));
+	(self->priv->implicits_dirs == NULL) ? NULL : (self->priv->implicits_dirs = (gee_collection_object_unref (self->priv->implicits_dirs), NULL));
+	(self->priv->loaded_ns == NULL) ? NULL : (self->priv->loaded_ns = (gee_collection_object_unref (self->priv->loaded_ns), NULL));
 	G_OBJECT_CLASS (gtkaml_implicits_store_parent_class)->finalize (obj);
 }
 
@@ -588,16 +603,16 @@ GType gtkaml_implicits_store_get_type (void) {
 
 
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
-	if (array != NULL && destroy_func != NULL) {
+	if ((array != NULL) && (destroy_func != NULL)) {
 		int i;
 		if (array_length >= 0)
 		for (i = 0; i < array_length; i = i + 1) {
-			if (((gpointer*) (array))[i] != NULL)
-			destroy_func (((gpointer*) (array))[i]);
+			if (((gpointer*) array)[i] != NULL)
+			destroy_func (((gpointer*) array)[i]);
 		}
 		else
-		for (i = 0; ((gpointer*) (array))[i] != NULL; i = i + 1) {
-			destroy_func (((gpointer*) (array))[i]);
+		for (i = 0; ((gpointer*) array)[i] != NULL; i = i + 1) {
+			destroy_func (((gpointer*) array)[i]);
 		}
 	}
 	g_free (array);
@@ -609,7 +624,7 @@ static int _vala_strcmp0 (const char * str1, const char * str2) {
 		return -(str1 != str2);
 	}
 	if (str2 == NULL) {
-		return (str1 != str2);
+		return str1 != str2;
 	}
 	return strcmp (str1, str2);
 }
