@@ -64,8 +64,8 @@ void gtkaml_method_set_name (GtkamlMethod* self, const char* value) {
 	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_name = (g_free (self->priv->_name), NULL)), _tmp2);
-	g_object_notify (((GObject *) (self)), "name");
+	self->priv->_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_strdup (_tmp1)), self->priv->_name = (g_free (self->priv->_name), NULL), _tmp2);
+	g_object_notify ((GObject *) self, "name");
 }
 
 
@@ -81,8 +81,8 @@ void gtkaml_method_set_parameter_attributes (GtkamlMethod* self, GeeList* value)
 	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_parameter_attributes = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : gee_collection_object_ref (_tmp1))), (self->priv->_parameter_attributes == NULL ? NULL : (self->priv->_parameter_attributes = (gee_collection_object_unref (self->priv->_parameter_attributes), NULL))), _tmp2);
-	g_object_notify (((GObject *) (self)), "parameter-attributes");
+	self->priv->_parameter_attributes = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : gee_collection_object_ref (_tmp1)), (self->priv->_parameter_attributes == NULL) ? NULL : (self->priv->_parameter_attributes = (gee_collection_object_unref (self->priv->_parameter_attributes), NULL)), _tmp2);
+	g_object_notify ((GObject *) self, "parameter-attributes");
 }
 
 
@@ -98,8 +98,8 @@ static GObject * gtkaml_method_constructor (GType type, guint n_construct_proper
 	{
 		GeeArrayList* _tmp0;
 		_tmp0 = NULL;
-		gtkaml_method_set_parameter_attributes (self, ((GeeList*) ((_tmp0 = gee_array_list_new (GTKAML_TYPE_ATTRIBUTE, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal)))));
-		(_tmp0 == NULL ? NULL : (_tmp0 = (gee_collection_object_unref (_tmp0), NULL)));
+		gtkaml_method_set_parameter_attributes (self, (GeeList*) (_tmp0 = gee_array_list_new (GTKAML_TYPE_ATTRIBUTE, (GBoxedCopyFunc) g_object_ref, g_object_unref, g_direct_equal)));
+		(_tmp0 == NULL) ? NULL : (_tmp0 = (gee_collection_object_unref (_tmp0), NULL));
 	}
 	return obj;
 }
@@ -160,7 +160,7 @@ static void gtkaml_method_finalize (GObject* obj) {
 	GtkamlMethod * self;
 	self = GTKAML_METHOD (obj);
 	self->priv->_name = (g_free (self->priv->_name), NULL);
-	(self->priv->_parameter_attributes == NULL ? NULL : (self->priv->_parameter_attributes = (gee_collection_object_unref (self->priv->_parameter_attributes), NULL)));
+	(self->priv->_parameter_attributes == NULL) ? NULL : (self->priv->_parameter_attributes = (gee_collection_object_unref (self->priv->_parameter_attributes), NULL));
 	G_OBJECT_CLASS (gtkaml_method_parent_class)->finalize (obj);
 }
 
