@@ -37,7 +37,6 @@
 
 struct _GtkamlParserPrivate {
 	ValaCodeContext* context;
-	ValaSourceFile* current_source_file;
 	GtkamlImplicitsStore* implicits_store;
 };
 
@@ -54,8 +53,7 @@ static void gtkaml_parser_finalize (ValaCodeVisitor* obj);
 
 GtkamlParser* gtkaml_parser_construct (GType object_type) {
 	GtkamlParser* self;
-	self = ((GtkamlParser*) (g_type_create_instance (object_type)));
-	self = ((GtkamlParser*) (vala_parser_construct (object_type)));
+	self = (GtkamlParser*) vala_parser_construct (object_type);
 	return self;
 }
 
@@ -81,7 +79,7 @@ void gtkaml_parser_parse (GtkamlParser* self, ValaCodeContext* context, char** i
 				const char* _tmp0;
 				char* implicits_dirs;
 				_tmp0 = NULL;
-				implicits_dirs = (_tmp0 = *implicits_dirs_it, (_tmp0 == NULL ? NULL : g_strdup (_tmp0)));
+				implicits_dirs = (_tmp0 = *implicits_dirs_it, (_tmp0 == NULL) ? NULL : g_strdup (_tmp0));
 				{
 					gtkaml_implicits_store_add_implicits_dir (self->priv->implicits_store, implicits_dirs);
 					implicits_dirs = (g_free (implicits_dirs), NULL);
@@ -99,7 +97,7 @@ void gtkaml_parser_parse (GtkamlParser* self, ValaCodeContext* context, char** i
 			const char* _tmp1;
 			char* datadir;
 			_tmp1 = NULL;
-			datadir = (_tmp1 = *datadir_it, (_tmp1 == NULL ? NULL : g_strdup (_tmp1)));
+			datadir = (_tmp1 = *datadir_it, (_tmp1 == NULL) ? NULL : g_strdup (_tmp1));
 			{
 				char* filename;
 				filename = g_build_filename (datadir, "gtkaml", "implicits", NULL);
@@ -113,17 +111,24 @@ void gtkaml_parser_parse (GtkamlParser* self, ValaCodeContext* context, char** i
 	}
 	_tmp3 = NULL;
 	_tmp2 = NULL;
-	self->priv->context = (_tmp3 = (_tmp2 = context, (_tmp2 == NULL ? NULL : vala_code_context_ref (_tmp2))), (self->priv->context == NULL ? NULL : (self->priv->context = (vala_code_context_unref (self->priv->context), NULL))), _tmp3);
+	self->priv->context = (_tmp3 = (_tmp2 = context, (_tmp2 == NULL) ? NULL : vala_code_context_ref (_tmp2)), (self->priv->context == NULL) ? NULL : (self->priv->context = (vala_code_context_unref (self->priv->context), NULL)), _tmp3);
 	vala_parser_parse (VALA_PARSER (self), context);
 }
 
 
 static void gtkaml_parser_real_visit_source_file (ValaCodeVisitor* base, ValaSourceFile* source_file) {
 	GtkamlParser * self;
-	self = ((GtkamlParser*) (base));
+	gboolean _tmp0;
+	self = (GtkamlParser*) base;
 	g_return_if_fail (source_file != NULL);
-	if (g_str_has_suffix (vala_source_file_get_filename (source_file), ".vala") || g_str_has_suffix (vala_source_file_get_filename (source_file), ".vapi")) {
-		VALA_CODE_VISITOR_CLASS (gtkaml_parser_parent_class)->visit_source_file (((ValaCodeVisitor*) (VALA_PARSER (self))), source_file);
+	_tmp0 = FALSE;
+	if (g_str_has_suffix (vala_source_file_get_filename (source_file), ".vala")) {
+		_tmp0 = TRUE;
+	} else {
+		_tmp0 = g_str_has_suffix (vala_source_file_get_filename (source_file), ".vapi");
+	}
+	if (_tmp0) {
+		VALA_CODE_VISITOR_CLASS (gtkaml_parser_parent_class)->visit_source_file ((ValaCodeVisitor*) VALA_PARSER (self), source_file);
 	} else {
 		if (g_str_has_suffix (vala_source_file_get_filename (source_file), ".gtkaml")) {
 			gtkaml_parser_parse_gtkaml_file (self, source_file);
@@ -149,28 +154,28 @@ static void gtkaml_parser_real_parse_gtkaml_file (GtkamlParser* self, ValaSource
 			sax_parser = gtkaml_sax_parser_new (self->priv->context, dummy_file);
 			root_class_definition = gtkaml_sax_parser_parse (sax_parser);
 			if (vala_report_get_errors () != 0) {
-				(dummy_file == NULL ? NULL : (dummy_file = (vala_source_file_unref (dummy_file), NULL)));
-				(sax_parser == NULL ? NULL : (sax_parser = (g_object_unref (sax_parser), NULL)));
-				(root_class_definition == NULL ? NULL : (root_class_definition = (g_object_unref (root_class_definition), NULL)));
+				(dummy_file == NULL) ? NULL : (dummy_file = (vala_source_file_unref (dummy_file), NULL));
+				(sax_parser == NULL) ? NULL : (sax_parser = (g_object_unref (sax_parser), NULL));
+				(root_class_definition == NULL) ? NULL : (root_class_definition = (g_object_unref (root_class_definition), NULL));
 				return;
 			}
 			implicitsResolver = gtkaml_implicits_resolver_new (self->priv->context, self->priv->implicits_store);
-			gtkaml_implicits_resolver_resolve (implicitsResolver, ((GtkamlClassDefinition*) (root_class_definition)));
+			gtkaml_implicits_resolver_resolve (implicitsResolver, (GtkamlClassDefinition*) root_class_definition);
 			if (vala_report_get_errors () != 0) {
-				(dummy_file == NULL ? NULL : (dummy_file = (vala_source_file_unref (dummy_file), NULL)));
-				(sax_parser == NULL ? NULL : (sax_parser = (g_object_unref (sax_parser), NULL)));
-				(root_class_definition == NULL ? NULL : (root_class_definition = (g_object_unref (root_class_definition), NULL)));
-				(implicitsResolver == NULL ? NULL : (implicitsResolver = (g_object_unref (implicitsResolver), NULL)));
+				(dummy_file == NULL) ? NULL : (dummy_file = (vala_source_file_unref (dummy_file), NULL));
+				(sax_parser == NULL) ? NULL : (sax_parser = (g_object_unref (sax_parser), NULL));
+				(root_class_definition == NULL) ? NULL : (root_class_definition = (g_object_unref (root_class_definition), NULL));
+				(implicitsResolver == NULL) ? NULL : (implicitsResolver = (g_object_unref (implicitsResolver), NULL));
 				return;
 			}
 			code_generator = gtkaml_code_generator_new (self->priv->context);
-			gtkaml_code_generator_generate (code_generator, ((GtkamlClassDefinition*) (root_class_definition)));
+			gtkaml_code_generator_generate (code_generator, (GtkamlClassDefinition*) root_class_definition);
 			if (vala_report_get_errors () != 0) {
-				(dummy_file == NULL ? NULL : (dummy_file = (vala_source_file_unref (dummy_file), NULL)));
-				(sax_parser == NULL ? NULL : (sax_parser = (g_object_unref (sax_parser), NULL)));
-				(root_class_definition == NULL ? NULL : (root_class_definition = (g_object_unref (root_class_definition), NULL)));
-				(implicitsResolver == NULL ? NULL : (implicitsResolver = (g_object_unref (implicitsResolver), NULL)));
-				(code_generator == NULL ? NULL : (code_generator = (g_object_unref (code_generator), NULL)));
+				(dummy_file == NULL) ? NULL : (dummy_file = (vala_source_file_unref (dummy_file), NULL));
+				(sax_parser == NULL) ? NULL : (sax_parser = (g_object_unref (sax_parser), NULL));
+				(root_class_definition == NULL) ? NULL : (root_class_definition = (g_object_unref (root_class_definition), NULL));
+				(implicitsResolver == NULL) ? NULL : (implicitsResolver = (g_object_unref (implicitsResolver), NULL));
+				(code_generator == NULL) ? NULL : (code_generator = (g_object_unref (code_generator), NULL));
 				return;
 			}
 			vala_contents = gtkaml_code_generator_yield (code_generator);
@@ -178,9 +183,10 @@ static void gtkaml_parser_real_parse_gtkaml_file (GtkamlParser* self, ValaSource
 				char* _tmp0;
 				char* _tmp1;
 				char* vala_filename;
+				gboolean _tmp2;
 				_tmp0 = NULL;
 				_tmp1 = NULL;
-				vala_filename = (_tmp1 = g_strconcat ((_tmp0 = g_strndup (vala_source_file_get_filename (gtkaml_source_file), ((gulong) (g_utf8_strlen (vala_source_file_get_filename (gtkaml_source_file), -1) - g_utf8_strlen (".gtkaml", -1))))), ".vala", NULL), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
+				vala_filename = (_tmp1 = g_strconcat (_tmp0 = g_strndup (vala_source_file_get_filename (gtkaml_source_file), (gulong) (g_utf8_strlen (vala_source_file_get_filename (gtkaml_source_file), -1) - g_utf8_strlen (".gtkaml", -1))), ".vala", NULL), _tmp0 = (g_free (_tmp0), NULL), _tmp1);
 				g_file_set_contents (vala_filename, vala_contents, -1, &inner_error);
 				if (inner_error != NULL) {
 					if (inner_error->domain == G_FILE_ERROR) {
@@ -190,17 +196,23 @@ static void gtkaml_parser_real_parse_gtkaml_file (GtkamlParser* self, ValaSource
 					g_clear_error (&inner_error);
 				}
 				vala_source_file_set_filename (gtkaml_source_file, vala_filename);
-				VALA_CODE_VISITOR_CLASS (gtkaml_parser_parent_class)->visit_source_file (((ValaCodeVisitor*) (VALA_PARSER (self))), gtkaml_source_file);
-				if (vala_report_get_errors () == 0 && !vala_code_context_get_save_temps (self->priv->context)) {
+				VALA_CODE_VISITOR_CLASS (gtkaml_parser_parent_class)->visit_source_file ((ValaCodeVisitor*) VALA_PARSER (self), gtkaml_source_file);
+				_tmp2 = FALSE;
+				if (vala_report_get_errors () == 0) {
+					_tmp2 = !vala_code_context_get_save_temps (self->priv->context);
+				} else {
+					_tmp2 = FALSE;
+				}
+				if (_tmp2) {
 					g_unlink (vala_filename);
 				}
 				vala_filename = (g_free (vala_filename), NULL);
 			}
-			(dummy_file == NULL ? NULL : (dummy_file = (vala_source_file_unref (dummy_file), NULL)));
-			(sax_parser == NULL ? NULL : (sax_parser = (g_object_unref (sax_parser), NULL)));
-			(root_class_definition == NULL ? NULL : (root_class_definition = (g_object_unref (root_class_definition), NULL)));
-			(implicitsResolver == NULL ? NULL : (implicitsResolver = (g_object_unref (implicitsResolver), NULL)));
-			(code_generator == NULL ? NULL : (code_generator = (g_object_unref (code_generator), NULL)));
+			(dummy_file == NULL) ? NULL : (dummy_file = (vala_source_file_unref (dummy_file), NULL));
+			(sax_parser == NULL) ? NULL : (sax_parser = (g_object_unref (sax_parser), NULL));
+			(root_class_definition == NULL) ? NULL : (root_class_definition = (g_object_unref (root_class_definition), NULL));
+			(implicitsResolver == NULL) ? NULL : (implicitsResolver = (g_object_unref (implicitsResolver), NULL));
+			(code_generator == NULL) ? NULL : (code_generator = (g_object_unref (code_generator), NULL));
 			vala_contents = (g_free (vala_contents), NULL);
 		}
 		goto __finally3;
@@ -211,16 +223,16 @@ static void gtkaml_parser_real_parse_gtkaml_file (GtkamlParser* self, ValaSource
 			inner_error = NULL;
 			{
 				vala_report_error (NULL, e->message);
-				(e == NULL ? NULL : (e = (g_error_free (e), NULL)));
+				(e == NULL) ? NULL : (e = (g_error_free (e), NULL));
 			}
 		}
 		__finally3:
 		;
 	} else {
-		char* _tmp2;
-		_tmp2 = NULL;
-		vala_report_error (NULL, (_tmp2 = g_strdup_printf ("%s not found", vala_source_file_get_filename (gtkaml_source_file))));
-		_tmp2 = (g_free (_tmp2), NULL);
+		char* _tmp3;
+		_tmp3 = NULL;
+		vala_report_error (NULL, _tmp3 = g_strdup_printf ("%s not found", vala_source_file_get_filename (gtkaml_source_file)));
+		_tmp3 = (g_free (_tmp3), NULL);
 	}
 }
 
@@ -248,9 +260,8 @@ static void gtkaml_parser_instance_init (GtkamlParser * self) {
 static void gtkaml_parser_finalize (ValaCodeVisitor* obj) {
 	GtkamlParser * self;
 	self = GTKAML_PARSER (obj);
-	(self->priv->context == NULL ? NULL : (self->priv->context = (vala_code_context_unref (self->priv->context), NULL)));
-	(self->priv->current_source_file == NULL ? NULL : (self->priv->current_source_file = (vala_source_file_unref (self->priv->current_source_file), NULL)));
-	(self->priv->implicits_store == NULL ? NULL : (self->priv->implicits_store = (g_object_unref (self->priv->implicits_store), NULL)));
+	(self->priv->context == NULL) ? NULL : (self->priv->context = (vala_code_context_unref (self->priv->context), NULL));
+	(self->priv->implicits_store == NULL) ? NULL : (self->priv->implicits_store = (g_object_unref (self->priv->implicits_store), NULL));
 	VALA_CODE_VISITOR_CLASS (gtkaml_parser_parent_class)->finalize (obj);
 }
 
