@@ -43,21 +43,21 @@ GtkamlReferenceClassDefinition* gtkaml_reference_class_definition_construct (GTy
 	g_return_val_if_fail (base_ns != NULL, NULL);
 	g_return_val_if_fail (base_type != NULL, NULL);
 	self = g_object_newv (object_type, 0, NULL);
-	gtkaml_class_definition_set_source_reference (((GtkamlClassDefinition*) (self)), source_reference);
-	gtkaml_class_definition_set_base_ns (((GtkamlClassDefinition*) (self)), base_ns);
-	gtkaml_class_definition_set_identifier (((GtkamlClassDefinition*) (self)), reference);
-	gtkaml_class_definition_set_base_type (((GtkamlClassDefinition*) (self)), base_type);
-	gtkaml_class_definition_set_definition_scope (((GtkamlClassDefinition*) (self)), 0);
-	gtkaml_class_definition_set_parent_container (((GtkamlClassDefinition*) (self)), parent_container);
+	gtkaml_class_definition_set_source_reference ((GtkamlClassDefinition*) self, source_reference);
+	gtkaml_class_definition_set_base_ns ((GtkamlClassDefinition*) self, base_ns);
+	gtkaml_class_definition_set_identifier ((GtkamlClassDefinition*) self, reference);
+	gtkaml_class_definition_set_base_type ((GtkamlClassDefinition*) self, base_type);
+	gtkaml_class_definition_set_definition_scope ((GtkamlClassDefinition*) self, 0);
+	gtkaml_class_definition_set_parent_container ((GtkamlClassDefinition*) self, parent_container);
 	_tmp0 = NULL;
-	gtkaml_class_definition_set_attrs (((GtkamlClassDefinition*) (self)), ((GeeList*) ((_tmp0 = gee_array_list_new (GTKAML_TYPE_ATTRIBUTE, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal)))));
-	(_tmp0 == NULL ? NULL : (_tmp0 = (gee_collection_object_unref (_tmp0), NULL)));
-	gtkaml_class_definition_set_construct_method (((GtkamlClassDefinition*) (self)), NULL);
+	gtkaml_class_definition_set_attrs ((GtkamlClassDefinition*) self, (GeeList*) (_tmp0 = gee_array_list_new (GTKAML_TYPE_ATTRIBUTE, (GBoxedCopyFunc) g_object_ref, g_object_unref, g_direct_equal)));
+	(_tmp0 == NULL) ? NULL : (_tmp0 = (gee_collection_object_unref (_tmp0), NULL));
+	gtkaml_class_definition_set_construct_method ((GtkamlClassDefinition*) self, NULL);
 	_tmp1 = NULL;
-	gtkaml_class_definition_set_children (((GtkamlClassDefinition*) (self)), ((GeeList*) ((_tmp1 = gee_array_list_new (GTKAML_TYPE_CLASS_DEFINITION, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal)))));
-	(_tmp1 == NULL ? NULL : (_tmp1 = (gee_collection_object_unref (_tmp1), NULL)));
-	gtkaml_class_definition_set_construct_code (((GtkamlClassDefinition*) (self)), NULL);
-	gtkaml_class_definition_set_preconstruct_code (((GtkamlClassDefinition*) (self)), NULL);
+	gtkaml_class_definition_set_children ((GtkamlClassDefinition*) self, (GeeList*) (_tmp1 = gee_array_list_new (GTKAML_TYPE_CLASS_DEFINITION, (GBoxedCopyFunc) g_object_ref, g_object_unref, g_direct_equal)));
+	(_tmp1 == NULL) ? NULL : (_tmp1 = (gee_collection_object_unref (_tmp1), NULL));
+	gtkaml_class_definition_set_construct_code ((GtkamlClassDefinition*) self, NULL);
+	gtkaml_class_definition_set_preconstruct_code ((GtkamlClassDefinition*) self, NULL);
 	return self;
 }
 
