@@ -61,26 +61,26 @@ GtkamlRootClassDefinition* gtkaml_root_class_definition_construct (GType object_
 	g_return_val_if_fail (base_ns != NULL, NULL);
 	g_return_val_if_fail (base_type != NULL, NULL);
 	self = g_object_newv (object_type, 0, NULL);
-	gtkaml_class_definition_set_source_reference (((GtkamlClassDefinition*) (self)), source_reference);
-	gtkaml_class_definition_set_base_ns (((GtkamlClassDefinition*) (self)), base_ns);
-	gtkaml_class_definition_set_identifier (((GtkamlClassDefinition*) (self)), identifier);
-	gtkaml_class_definition_set_base_type (((GtkamlClassDefinition*) (self)), base_type);
-	gtkaml_class_definition_set_definition_scope (((GtkamlClassDefinition*) (self)), definition_scope);
-	gtkaml_class_definition_set_parent_container (((GtkamlClassDefinition*) (self)), parent_container);
+	gtkaml_class_definition_set_source_reference ((GtkamlClassDefinition*) self, source_reference);
+	gtkaml_class_definition_set_base_ns ((GtkamlClassDefinition*) self, base_ns);
+	gtkaml_class_definition_set_identifier ((GtkamlClassDefinition*) self, identifier);
+	gtkaml_class_definition_set_base_type ((GtkamlClassDefinition*) self, base_type);
+	gtkaml_class_definition_set_definition_scope ((GtkamlClassDefinition*) self, definition_scope);
+	gtkaml_class_definition_set_parent_container ((GtkamlClassDefinition*) self, parent_container);
 	_tmp0 = NULL;
-	gtkaml_class_definition_set_attrs (((GtkamlClassDefinition*) (self)), ((GeeList*) ((_tmp0 = gee_array_list_new (GTKAML_TYPE_ATTRIBUTE, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal)))));
-	(_tmp0 == NULL ? NULL : (_tmp0 = (gee_collection_object_unref (_tmp0), NULL)));
-	gtkaml_class_definition_set_construct_method (((GtkamlClassDefinition*) (self)), NULL);
+	gtkaml_class_definition_set_attrs ((GtkamlClassDefinition*) self, (GeeList*) (_tmp0 = gee_array_list_new (GTKAML_TYPE_ATTRIBUTE, (GBoxedCopyFunc) g_object_ref, g_object_unref, g_direct_equal)));
+	(_tmp0 == NULL) ? NULL : (_tmp0 = (gee_collection_object_unref (_tmp0), NULL));
+	gtkaml_class_definition_set_construct_method ((GtkamlClassDefinition*) self, NULL);
 	_tmp1 = NULL;
-	gtkaml_class_definition_set_children (((GtkamlClassDefinition*) (self)), ((GeeList*) ((_tmp1 = gee_array_list_new (GTKAML_TYPE_CLASS_DEFINITION, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal)))));
-	(_tmp1 == NULL ? NULL : (_tmp1 = (gee_collection_object_unref (_tmp1), NULL)));
-	gtkaml_class_definition_set_construct_code (((GtkamlClassDefinition*) (self)), NULL);
-	gtkaml_class_definition_set_preconstruct_code (((GtkamlClassDefinition*) (self)), NULL);
+	gtkaml_class_definition_set_children ((GtkamlClassDefinition*) self, (GeeList*) (_tmp1 = gee_array_list_new (GTKAML_TYPE_CLASS_DEFINITION, (GBoxedCopyFunc) g_object_ref, g_object_unref, g_direct_equal)));
+	(_tmp1 == NULL) ? NULL : (_tmp1 = (gee_collection_object_unref (_tmp1), NULL));
+	gtkaml_class_definition_set_construct_code ((GtkamlClassDefinition*) self, NULL);
+	gtkaml_class_definition_set_preconstruct_code ((GtkamlClassDefinition*) self, NULL);
 	gtkaml_root_class_definition_set_target_name (self, NULL);
 	gtkaml_root_class_definition_set_target_namespace (self, NULL);
 	_tmp2 = NULL;
-	gtkaml_root_class_definition_set_code (self, ((GeeList*) ((_tmp2 = gee_array_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) (g_strdup)), g_free, g_direct_equal)))));
-	(_tmp2 == NULL ? NULL : (_tmp2 = (gee_collection_object_unref (_tmp2), NULL)));
+	gtkaml_root_class_definition_set_code (self, (GeeList*) (_tmp2 = gee_array_list_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, g_direct_equal)));
+	(_tmp2 == NULL) ? NULL : (_tmp2 = (gee_collection_object_unref (_tmp2), NULL));
 	gtkaml_root_class_definition_set_implements (self, NULL);
 	gtkaml_root_class_definition_set_original_first_code_line (self, -1);
 	return self;
@@ -104,8 +104,8 @@ void gtkaml_root_class_definition_set_prefixes_namespaces (GtkamlRootClassDefini
 	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_prefixes_namespaces = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : gee_collection_object_ref (_tmp1))), (self->priv->_prefixes_namespaces == NULL ? NULL : (self->priv->_prefixes_namespaces = (gee_collection_object_unref (self->priv->_prefixes_namespaces), NULL))), _tmp2);
-	g_object_notify (((GObject *) (self)), "prefixes-namespaces");
+	self->priv->_prefixes_namespaces = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : gee_collection_object_ref (_tmp1)), (self->priv->_prefixes_namespaces == NULL) ? NULL : (self->priv->_prefixes_namespaces = (gee_collection_object_unref (self->priv->_prefixes_namespaces), NULL)), _tmp2);
+	g_object_notify ((GObject *) self, "prefixes-namespaces");
 }
 
 
@@ -121,8 +121,8 @@ void gtkaml_root_class_definition_set_target_name (GtkamlRootClassDefinition* se
 	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_target_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_target_name = (g_free (self->priv->_target_name), NULL)), _tmp2);
-	g_object_notify (((GObject *) (self)), "target-name");
+	self->priv->_target_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_strdup (_tmp1)), self->priv->_target_name = (g_free (self->priv->_target_name), NULL), _tmp2);
+	g_object_notify ((GObject *) self, "target-name");
 }
 
 
@@ -138,8 +138,8 @@ void gtkaml_root_class_definition_set_target_namespace (GtkamlRootClassDefinitio
 	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_target_namespace = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_target_namespace = (g_free (self->priv->_target_namespace), NULL)), _tmp2);
-	g_object_notify (((GObject *) (self)), "target-namespace");
+	self->priv->_target_namespace = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_strdup (_tmp1)), self->priv->_target_namespace = (g_free (self->priv->_target_namespace), NULL), _tmp2);
+	g_object_notify ((GObject *) self, "target-namespace");
 }
 
 
@@ -155,8 +155,8 @@ void gtkaml_root_class_definition_set_code (GtkamlRootClassDefinition* self, Gee
 	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_code = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : gee_collection_object_ref (_tmp1))), (self->priv->_code == NULL ? NULL : (self->priv->_code = (gee_collection_object_unref (self->priv->_code), NULL))), _tmp2);
-	g_object_notify (((GObject *) (self)), "code");
+	self->priv->_code = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : gee_collection_object_ref (_tmp1)), (self->priv->_code == NULL) ? NULL : (self->priv->_code = (gee_collection_object_unref (self->priv->_code), NULL)), _tmp2);
+	g_object_notify ((GObject *) self, "code");
 }
 
 
@@ -169,7 +169,7 @@ gint gtkaml_root_class_definition_get_original_first_code_line (GtkamlRootClassD
 void gtkaml_root_class_definition_set_original_first_code_line (GtkamlRootClassDefinition* self, gint value) {
 	g_return_if_fail (self != NULL);
 	self->priv->_original_first_code_line = value;
-	g_object_notify (((GObject *) (self)), "original-first-code-line");
+	g_object_notify ((GObject *) self, "original-first-code-line");
 }
 
 
@@ -185,8 +185,8 @@ void gtkaml_root_class_definition_set_implements (GtkamlRootClassDefinition* sel
 	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_implements = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_implements = (g_free (self->priv->_implements), NULL)), _tmp2);
-	g_object_notify (((GObject *) (self)), "implements");
+	self->priv->_implements = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_strdup (_tmp1)), self->priv->_implements = (g_free (self->priv->_implements), NULL), _tmp2);
+	g_object_notify ((GObject *) self, "implements");
 }
 
 
@@ -271,10 +271,10 @@ static void gtkaml_root_class_definition_instance_init (GtkamlRootClassDefinitio
 static void gtkaml_root_class_definition_finalize (GObject* obj) {
 	GtkamlRootClassDefinition * self;
 	self = GTKAML_ROOT_CLASS_DEFINITION (obj);
-	(self->priv->_prefixes_namespaces == NULL ? NULL : (self->priv->_prefixes_namespaces = (gee_collection_object_unref (self->priv->_prefixes_namespaces), NULL)));
+	(self->priv->_prefixes_namespaces == NULL) ? NULL : (self->priv->_prefixes_namespaces = (gee_collection_object_unref (self->priv->_prefixes_namespaces), NULL));
 	self->priv->_target_name = (g_free (self->priv->_target_name), NULL);
 	self->priv->_target_namespace = (g_free (self->priv->_target_namespace), NULL);
-	(self->priv->_code == NULL ? NULL : (self->priv->_code = (gee_collection_object_unref (self->priv->_code), NULL)));
+	(self->priv->_code == NULL) ? NULL : (self->priv->_code = (gee_collection_object_unref (self->priv->_code), NULL));
 	self->priv->_implements = (g_free (self->priv->_implements), NULL);
 	G_OBJECT_CLASS (gtkaml_root_class_definition_parent_class)->finalize (obj);
 }
