@@ -44,7 +44,7 @@ GtkamlSimpleAttribute* gtkaml_simple_attribute_construct (GType object_type, con
 	g_return_val_if_fail (name != NULL, NULL);
 	g_return_val_if_fail (value != NULL, NULL);
 	self = g_object_newv (object_type, 0, NULL);
-	gtkaml_attribute_set_name (((GtkamlAttribute*) (self)), name);
+	gtkaml_attribute_set_name ((GtkamlAttribute*) self, name);
 	gtkaml_simple_attribute_set_value (self, value);
 	return self;
 }
@@ -67,8 +67,8 @@ void gtkaml_simple_attribute_set_value (GtkamlSimpleAttribute* self, const char*
 	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_value = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_value = (g_free (self->priv->_value), NULL)), _tmp2);
-	g_object_notify (((GObject *) (self)), "value");
+	self->priv->_value = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_strdup (_tmp1)), self->priv->_value = (g_free (self->priv->_value), NULL), _tmp2);
+	g_object_notify ((GObject *) self, "value");
 }
 
 
