@@ -81,7 +81,7 @@ GtkamlStateId gtkaml_state_get_state_id (GtkamlState* self) {
 void gtkaml_state_set_state_id (GtkamlState* self, GtkamlStateId value) {
 	g_return_if_fail (self != NULL);
 	self->priv->_state_id = value;
-	g_object_notify (((GObject *) (self)), "state-id");
+	g_object_notify ((GObject *) self, "state-id");
 }
 
 
@@ -97,8 +97,8 @@ void gtkaml_state_set_class_definition (GtkamlState* self, GtkamlClassDefinition
 	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_class_definition = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_class_definition == NULL ? NULL : (self->priv->_class_definition = (g_object_unref (self->priv->_class_definition), NULL))), _tmp2);
-	g_object_notify (((GObject *) (self)), "class-definition");
+	self->priv->_class_definition = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_object_ref (_tmp1)), (self->priv->_class_definition == NULL) ? NULL : (self->priv->_class_definition = (g_object_unref (self->priv->_class_definition), NULL)), _tmp2);
+	g_object_notify ((GObject *) self, "class-definition");
 }
 
 
@@ -114,8 +114,8 @@ void gtkaml_state_set_attribute (GtkamlState* self, GtkamlAttribute* value) {
 	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_attribute = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_attribute == NULL ? NULL : (self->priv->_attribute = (g_object_unref (self->priv->_attribute), NULL))), _tmp2);
-	g_object_notify (((GObject *) (self)), "attribute");
+	self->priv->_attribute = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_object_ref (_tmp1)), (self->priv->_attribute == NULL) ? NULL : (self->priv->_attribute = (g_object_unref (self->priv->_attribute), NULL)), _tmp2);
+	g_object_notify ((GObject *) self, "attribute");
 }
 
 
@@ -131,8 +131,8 @@ void gtkaml_state_set_attribute_name (GtkamlState* self, const char* value) {
 	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_attribute_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_attribute_name = (g_free (self->priv->_attribute_name), NULL)), _tmp2);
-	g_object_notify (((GObject *) (self)), "attribute-name");
+	self->priv->_attribute_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_strdup (_tmp1)), self->priv->_attribute_name = (g_free (self->priv->_attribute_name), NULL), _tmp2);
+	g_object_notify ((GObject *) self, "attribute-name");
 }
 
 
@@ -203,8 +203,8 @@ static void gtkaml_state_instance_init (GtkamlState * self) {
 static void gtkaml_state_finalize (GObject* obj) {
 	GtkamlState * self;
 	self = GTKAML_STATE (obj);
-	(self->priv->_class_definition == NULL ? NULL : (self->priv->_class_definition = (g_object_unref (self->priv->_class_definition), NULL)));
-	(self->priv->_attribute == NULL ? NULL : (self->priv->_attribute = (g_object_unref (self->priv->_attribute), NULL)));
+	(self->priv->_class_definition == NULL) ? NULL : (self->priv->_class_definition = (g_object_unref (self->priv->_class_definition), NULL));
+	(self->priv->_attribute == NULL) ? NULL : (self->priv->_attribute = (g_object_unref (self->priv->_attribute), NULL));
 	self->priv->_attribute_name = (g_free (self->priv->_attribute_name), NULL);
 	G_OBJECT_CLASS (gtkaml_state_parent_class)->finalize (obj);
 }
