@@ -47,7 +47,7 @@ static void gtkaml_state_stack_finalize (GObject* obj);
 void gtkaml_state_stack_push (GtkamlStateStack* self, GtkamlState* element) {
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (element != NULL);
-	gee_collection_add (((GeeCollection*) (self->priv->_array_list)), element);
+	gee_collection_add ((GeeCollection*) self->priv->_array_list, element);
 }
 
 
@@ -58,11 +58,11 @@ GtkamlState* gtkaml_state_stack_peek (GtkamlStateStack* self, gint backtrack) {
 	g_return_val_if_fail (self != NULL, NULL);
 	element = NULL;
 	_tmp0 = NULL;
-	size = gee_collection_get_size (((GeeCollection*) (((_tmp0 = self->priv->_array_list, (GEE_IS_LIST (_tmp0) ? ((GeeList*) (_tmp0)) : NULL))))));
+	size = gee_collection_get_size ((GeeCollection*) ((_tmp0 = self->priv->_array_list, GEE_IS_LIST (_tmp0) ? ((GeeList*) _tmp0) : NULL)));
 	if (size != 0) {
 		GtkamlState* _tmp1;
 		_tmp1 = NULL;
-		element = (_tmp1 = ((GtkamlState*) (gee_list_get (((GeeList*) (self->priv->_array_list)), size - 1 - backtrack))), (element == NULL ? NULL : (element = (g_object_unref (element), NULL))), _tmp1);
+		element = (_tmp1 = (GtkamlState*) gee_list_get ((GeeList*) self->priv->_array_list, (size - 1) - backtrack), (element == NULL) ? NULL : (element = (g_object_unref (element), NULL)), _tmp1);
 	}
 	return element;
 }
@@ -73,14 +73,14 @@ GtkamlState* gtkaml_state_stack_pop (GtkamlStateStack* self) {
 	g_return_val_if_fail (self != NULL, NULL);
 	element = gtkaml_state_stack_peek (self, 0);
 	if (element != NULL) {
-		gee_collection_remove (((GeeCollection*) (self->priv->_array_list)), element);
+		gee_collection_remove ((GeeCollection*) self->priv->_array_list, element);
 		return element;
 	} else {
 		GtkamlState* _tmp1;
 		_tmp1 = NULL;
-		return (_tmp1 = NULL, (element == NULL ? NULL : (element = (g_object_unref (element), NULL))), _tmp1);
+		return (_tmp1 = NULL, (element == NULL) ? NULL : (element = (g_object_unref (element), NULL)), _tmp1);
 	}
-	(element == NULL ? NULL : (element = (g_object_unref (element), NULL)));
+	(element == NULL) ? NULL : (element = (g_object_unref (element), NULL));
 }
 
 
@@ -111,7 +111,7 @@ static void gtkaml_state_stack_set_array_list (GtkamlStateStack* self, GeeArrayL
 	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_array_list = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : gee_collection_object_ref (_tmp1))), (self->priv->_array_list == NULL ? NULL : (self->priv->_array_list = (gee_collection_object_unref (self->priv->_array_list), NULL))), _tmp2);
+	self->priv->_array_list = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : gee_collection_object_ref (_tmp1)), (self->priv->_array_list == NULL) ? NULL : (self->priv->_array_list = (gee_collection_object_unref (self->priv->_array_list), NULL)), _tmp2);
 }
 
 
@@ -127,8 +127,8 @@ static GObject * gtkaml_state_stack_constructor (GType type, guint n_construct_p
 	{
 		GeeArrayList* _tmp0;
 		_tmp0 = NULL;
-		gtkaml_state_stack_set_array_list (self, (_tmp0 = gee_array_list_new (GTKAML_TYPE_STATE, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal)));
-		(_tmp0 == NULL ? NULL : (_tmp0 = (gee_collection_object_unref (_tmp0), NULL)));
+		gtkaml_state_stack_set_array_list (self, _tmp0 = gee_array_list_new (GTKAML_TYPE_STATE, (GBoxedCopyFunc) g_object_ref, g_object_unref, g_direct_equal));
+		(_tmp0 == NULL) ? NULL : (_tmp0 = (gee_collection_object_unref (_tmp0), NULL));
 	}
 	return obj;
 }
@@ -174,7 +174,7 @@ static void gtkaml_state_stack_instance_init (GtkamlStateStack * self) {
 static void gtkaml_state_stack_finalize (GObject* obj) {
 	GtkamlStateStack * self;
 	self = GTKAML_STATE_STACK (obj);
-	(self->priv->_array_list == NULL ? NULL : (self->priv->_array_list = (gee_collection_object_unref (self->priv->_array_list), NULL)));
+	(self->priv->_array_list == NULL) ? NULL : (self->priv->_array_list = (gee_collection_object_unref (self->priv->_array_list), NULL));
 	G_OBJECT_CLASS (gtkaml_state_stack_parent_class)->finalize (obj);
 }
 
